using CommunityToolkit.WinUI.UI.Controls;
using Microsoft.UI.Xaml;
using Microsoft.UI.Xaml.Data;
using System.Collections.ObjectModel;
using System.Linq;


namespace DataGridEx
{
    public sealed partial class MainWindow : Window
    {
        public MainWindow()
        {
            this.InitializeComponent();
            LoadData();
            GroupData();
        }

        public ObservableCollection<Artikel> ArtikelListe { get; set; }

        public class Artikel
        {
            public string Artikelnummer { get; set; }
            public string Name { get; set; }
            public string Kurzbeschreibung { get; set; }
            public decimal Preis { get; set; }
            public string Lieferant { get; set; }
        }

        // Methode zum Laden der Daten
        private void LoadData()
        {
            ArtikelListe = new ObservableCollection<Artikel>
            {
                new Artikel { Artikelnummer = "A1001", Name = "Laptop", Kurzbeschreibung = "Leistungsstarker Laptop", Preis = 899.99m, Lieferant = "TechWare" },
                new Artikel { Artikelnummer = "A1002", Name = "Smartphone", Kurzbeschreibung = "5G-fhiges Smartphone", Preis = 599.99m, Lieferant = "PhoneCo" },
                new Artikel { Artikelnummer = "A1003", Name = "Tablet", Kurzbeschreibung = "10-Zoll Tablet", Preis = 299.99m, Lieferant = "TechWare" },
                new Artikel { Artikelnummer = "A1004", Name = "Monitor", Kurzbeschreibung = "4K-Monitor", Preis = 249.99m, Lieferant = "DisplayTech" },
                new Artikel { Artikelnummer = "A1005", Name = "Maus", Kurzbeschreibung = "Kabellose Maus", Preis = 29.99m, Lieferant = "InputPro" },
            };
        }

        private void GroupData()
        {
            // Erstellung einer CollectionViewSource zur Gruppierung der Artikel nach Lieferant
            var groupedArtikel = new CollectionViewSource
            {
                IsSourceGrouped = true, // Aktiviert die Gruppierung
                Source = from artikel in ArtikelListe
                         group artikel by artikel.Lieferant into artikelGroup
                         select artikelGroup
            };

            // Binden der gruppierten Daten direkt an das DataGrid
            MyDataGrid.ItemsSource = groupedArtikel.View; // Direkter Zugriff auf das DataGrid ber seinen Namen
        }

        private void MyDataGrid_LoadingRowGroup(object sender, DataGridRowGroupHeaderEventArgs e)
        {
            ICollectionViewGroup group = e.RowGroupHeader.CollectionViewGroup;
            Artikel item = group.GroupItems[0] as Artikel;
            e.RowGroupHeader.PropertyValue = item.Lieferant;
        }
    }
}
